# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/05/15 09:04
@Description: Description
@File: administrator.py
"""
from dataclasses import dataclass
from datetime import datetime

from api_requester.dto.base_dto import BaseDto


@dataclass
class Administrator(BaseDto):
    """
    The Administrator was generated by Generator from the Administrator.java file.
    """
    id: int = None
    loginName: str = None
    password: str = None
    active: bool = None
    firstName: str = None
    lastName: str = None
    creatorDt: datetime = None
    modifyDt: datetime = None
    creatorUid: str = None
    modifyUid: str = None
    isDelete: bool = None
    superAdmin: bool = None
    email: str = None
    ssoExternalId: str = None
    serialVersionUID: int = 1
