# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/05/15 09:04
@Description: Description
@File: administrator_api.py
"""
from api_requester.http.eclinical_requests import *


class AdministratorApi:
    """
    The AdministratorApi was generated by Generator from the AdministratorController.java file.
    """

    @post('/administrator/auth')
    def administrator_authentication_token_api(self, *args, **kwargs): ...

    @put('/administrator/password')
    def change_administrator_password_api(self, *args, **kwargs): ...

    @post('/administrator/user-list')
    def administrator_list_api(self, *args, **kwargs): ...

    @post('/administrator/user')
    def create_administrator_api(self, *args, **kwargs): ...

    @delete('/administrator/{administrator-id}/user')
    def delete_administrator_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/user')
    def update_administrator_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/user/change-password')
    def update_administrator_password_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/user/activation')
    def administrator_administrator_id_user_activation_api(self, *args, **kwargs): ...

    @get('/administrator/permission')
    def administrator_permission_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/permission')
    def set_administrator_permission_api(self, *args, **kwargs): ...

    @get('/administrator/{administrator-id}/permission')
    def get_administrator_permission_api(self, *args, **kwargs): ...

    @get('/initBusinessLogTable')
    def init_business_log_table_api(self, *args, **kwargs): ...

    @get('/alterBusinessLogTable')
    def alter_business_log_table_api(self, *args, **kwargs): ...

    @get('/count/permissions')
    def count_permissions_api(self, *args, **kwargs): ...

    @post('/execute-upload-sql/')
    def execute_upload_sql_api(self, *args, **kwargs): ...

    @post('/clean-release-package/')
    def clean_release_package_api(self, *args, **kwargs): ...

    @post('/execute-sql-in-portal/')
    def execute_upload_sql_in_portal_api(self, *args, **kwargs): ...

    @post('/execute-complex-sql-in-portal/')
    def execute_complex_sql_in_portal_api(self, *args, **kwargs): ...

    @post('/administrator/user/change-my-password')
    def change_my_password_api(self, *args, **kwargs): ...

    @post('/administrator/auth/sso/token')
    def administrator_auth_sso_token_api(self, *args, **kwargs): ...
