# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/26 16:09
@Description: Description
@File: change_user_password.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class ChangeUserPassword(BaseDto):
    """
    The ChangeUserPassword was generated by Generator from the ChangeUserPassword.java file.
    """
    userId: int = None
    newPassword: str = None
    oldPassword: str = None
