# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/05/15 09:04
@Description: Description
@File: administrator_query_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class AdministratorQueryDto(BaseDto):
    """
    The AdministratorQueryDto was generated by Generator from the AdministratorQueryDto.java file.
    """
    loginName: str = None
    firstName: str = None
    lastName: str = None
    email: str = None
    superAdmin: bool = None
    active: bool = None
